==> apache-juneau-7.2.2-src.zip: juneau-7.2.2/juneau-core/juneau-config/src/main/java/org/apache/juneau/config/event/ConfigEventListener.java <==
// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              *
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.config.event;

import java.util.*;

/**
 * Listener that can be used to listen for change events in config maps.
 */
public interface ConfigEventListener {

	/**
	 * Gets called immediately after a config file has been loaded.
	 *
	 * @param events The change events.
	 */
	void onConfigChange(List<ConfigEvent> events);
}

==> apache-juneau-9.1.0-src.zip: juneau-9.1.0/juneau-core/juneau-config/src/main/java/org/apache/juneau/config/event/ConfigEventListener.java <==
// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              *
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.config.event;

/**
 * Listener that can be used to listen for change events in config maps.
 */
public interface ConfigEventListener {

	/**
	 * Gets called immediately after a config file has been loaded.
	 *
	 * @param events The change events.
	 */
	void onConfigChange(ConfigEvents events);
}
